@@ -5,7 +5,7 @@ from typing import List, Optional, Union
 from git import Repo
 
 from gto.constants import NAME, STAGE, VERSION
-from gto.exceptions import WrongArgs
+from gto.exceptions import NoRepo, WrongArgs
 from gto.ext import EnrichmentInfo
 from gto.index import (
     EnrichmentManager,
@@ -19,7 +19,15 @@ from gto.tag import parse_name as parse_tag_name
 from gto.tag import parse_name_reference
 
 
-def get_index(repo: Union[str, Repo], file=False):
+def _is_gto_repo(repo: Union[str, Repo]):
+    """Check if repo is a gto repo"""
+    try:
+        return GitRegistry.from_repo(repo).is_gto_repo()
+    except NoRepo:
+        return False
+
+
+def _get_index(repo: Union[str, Repo], file=False):
     """Get index state"""
     if file:
         return FileIndexManager.from_path(
@@ -33,8 +41,8 @@ def _get_state(repo: Union[str, Repo]):
     return GitRegistry.from_repo(repo).get_state()
 
 
-def get_stages(repo: Union[str, Repo], allowed: bool = False):
-    return GitRegistry.from_repo(repo).get_stages(allowed=allowed)
+def get_stages(repo: Union[str, Repo], allowed: bool = False, used: bool = False):
+    return GitRegistry.from_repo(repo).get_stages(allowed=allowed, used=used)
 
 
 # TODO: make this work the same as CLI version
@@ -75,6 +83,8 @@ def register(
     bump_minor: bool = False,
     bump_patch: bool = False,
     stdout: bool = False,
+    author: Optional[str] = None,
+    author_email: Optional[str] = None,
 ):
     """Register new artifact version"""
     return GitRegistry.from_repo(repo).register(
@@ -86,6 +96,8 @@ def register(
         bump_minor=bump_minor,
         bump_patch=bump_patch,
         stdout=stdout,
+        author=author,
+        author_email=author_email,
     )
 
 
@@ -101,6 +113,8 @@ def promote(
     force: bool = False,
     skip_registration: bool = False,
     stdout: bool = False,
+    author: Optional[str] = None,
+    author_email: Optional[str] = None,
 ):
     """Assign stage to specific artifact version"""
     return GitRegistry.from_repo(repo).promote(
@@ -114,6 +128,8 @@ def promote(
         force=force,
         skip_registration=skip_registration,
         stdout=stdout,
+        author=author,
+        author_email=author_email,
     )
 
 
@@ -147,15 +163,7 @@ def find_versions_in_stage(
 def check_ref(repo: Union[str, Repo], ref: str):
     """Find out what have been registered/promoted in the provided ref"""
     reg = GitRegistry.from_repo(repo)
-    if ref.startswith("refs/tags/"):
-        ref = ref[len("refs/tags/") :]
-    if ref.startswith("refs/heads/"):
-        ref = reg.repo.commit(ref).hexsha
-    result = reg.check_ref(ref)
-    return {
-        action: {name: version.dict() for name, version in found.items()}
-        for action, found in result.items()
-    }
+    return reg.check_ref(ref)
 
 
 def show(
@@ -360,18 +368,18 @@ def history(  # pylint: disable=too-many-locals
 
     promotion = [
         OrderedDict(
-            timestamp=l.created_at,
+            timestamp=p.created_at,
             artifact=o.name,
             event="promotion",
-            version=format_hexsha(l.version),
-            stage=l.stage,
-            commit=format_hexsha(l.commit_hexsha),
-            author=l.author,
-            author_email=l.author_email,
-            message=l.message,
+            version=format_hexsha(p.version),
+            stage=p.stage,
+            commit=format_hexsha(p.commit_hexsha),
+            author=p.author,
+            author_email=p.author_email,
+            message=p.message,
         )
         for o in artifacts.values()
-        for l in o.stages
+        for p in o.stages
     ]
 
     events_order = {
@@ -383,7 +391,7 @@ def history(  # pylint: disable=too-many-locals
         commits + registration + promotion,
         key=lambda x: (x["timestamp"], events_order[x["event"]]),
     )
-    if ascending:
+    if not ascending:
         events.reverse()
     if artifact:
         events = [event for event in events if event["artifact"] == artifact]
