@@ -12,7 +12,7 @@ from typer import Argument, Option, Typer
 from typer.core import TyperCommand, TyperGroup
 
 import gto
-from gto.exceptions import GTOException, WrongArgs
+from gto.exceptions import GTOException, NotImplementedInGTO, WrongArgs
 from gto.ui import EMOJI_FAIL, EMOJI_GTO, EMOJI_OK, bold, cli_echo, color, echo
 from gto.utils import format_echo, make_ready_to_serialize
 
@@ -372,7 +372,7 @@ def annotate(
     """Update artifact metadata annotations
 
     Examples:
-       $ gto enrich nn --type model --path models/neural_network.h5
+       $ gto annotate nn --type model --path models/neural_network.h5
     """
     gto.api.annotate(
         repo,
@@ -430,7 +430,7 @@ def register(
         $ gto register nn --version v1.0.0
 
         Choose a part to bump version by:
-        $ gto register nn --bump minor
+        $ gto register nn --bump-minor
     """
     gto.api.register(
         repo=repo,
@@ -489,7 +489,7 @@ def promote(
         $ gto promote nn prod abcd123 --version v1.0.0
 
         Promote without increment
-        $ gto promote nn prod --ref HEAD --simple
+        $ gto promote nn prod HEAD --simple
     """
     if ref is not None:
         name_version = version
@@ -543,7 +543,7 @@ def which(
     ref: bool = option_ref_bool,
     all: bool = option_all,
     registered_only: bool = option_registered_only,
-    ascending: bool = option_ascending,
+    # ascending: bool = option_ascending,
 ):
     """Find the latest artifact version in a given stage
 
@@ -558,8 +558,8 @@ def which(
     )
     if version:
         if all:
-            if ascending:
-                version.reverse()
+            # if ascending:
+            #     version.reverse()
             format_echo([v.version for v in version], "lines")
         elif ref:
             echo(version.tag or version.commit_hexsha)
@@ -588,28 +588,64 @@ def parse_tag(
 def check_ref(
     repo: str = option_repo,
     ref: str = Argument(..., help="Git reference to analyze"),
-    json: bool = Option(False, "--json", is_flag=True, help="Output in JSON format"),
+    json: bool = option_json,
+    registration: bool = Option(
+        False, "--registration", is_flag=True, help="Check if ref registers a version"
+    ),
+    promotion: bool = Option(
+        False, "--promotion", is_flag=True, help="Check if ref promotes a version"
+    ),
+    name: bool = Option(False, "--name", is_flag=True, help="Output artifact name"),
+    version: bool = Option(
+        False, "--version", is_flag=True, help="Output artifact version"
+    ),
+    stage: bool = Option(False, "--stage", is_flag=True, help="Output artifact stage"),
 ):
     """Find out the artifact version registered/promoted with ref
 
     Examples:
         $ gto check-ref rf@v1.0.0
-        $ gto check-ref rf#prod
+        $ gto check-ref rf#prod --name
+        $ gto check-ref rf#prod --version
     """
-    result = gto.api.check_ref(repo, ref)
+    assert (
+        sum(bool(i) for i in (json, registration, promotion, name, version, stage)) <= 1
+    ), "Only one output formatting flags is allowed"
+    result = {
+        action: {name: version.dict() for name, version in found.items()}
+        for action, found in gto.api.check_ref(repo, ref).items()
+    }
+    version_dict = list(result["version"].values())[0] if result["version"] else {}
+    stage_dict = list(result["stage"].values())[0] if result["stage"] else {}
     if json:
         format_echo(result, "json")
-    else:
-        if result["version"]:
-            v = list(result["version"].values())[0]
-            echo(
-                f"""{EMOJI_OK} Version "{v["name"]}" of artifact "{v["artifact"]}" was registered"""
-            )
-        if result["stage"]:
-            s = list(result["stage"].values())[0]
-            echo(
-                f"""{EMOJI_OK} Version "{s["version"]}" of artifact "{s["artifact"]}" was promoted to "{s["stage"]}" stage"""
+    elif name:
+        if version_dict:
+            echo(version_dict["artifact"])
+        if stage_dict:
+            echo(stage_dict["artifact"])
+    elif version:
+        if version_dict:
+            echo(version_dict["name"])
+        if stage_dict:
+            echo(stage_dict["version"])
+    elif stage:
+        if version_dict:
+            raise NotImplementedInGTO(
+                "--stage is not implemented for version promotion git tag"
             )
+        if stage_dict:
+            echo(stage_dict["stage"])
+    elif (registration or not promotion) and version_dict:
+        echo(
+            f"""{EMOJI_OK} Version "{version_dict["name"]}" of artifact """
+            f""""{version_dict["artifact"]}" was registered"""
+        )
+    elif (promotion or not registration) and stage_dict:
+        echo(
+            f"""{EMOJI_OK} Version "{stage_dict["version"]}" of artifact """
+            f""""{stage_dict["artifact"]}" was promoted to "{stage_dict["stage"]}" stage"""
+        )
 
 
 @gto_command(section=CommandGroups.querying)
@@ -737,6 +773,14 @@ def stages(
         help="Show allowed stages from config",
         show_default=True,
     ),
+    used: bool = Option(
+        False,
+        "--used",
+        is_flag=True,
+        help="Show stages that were ever used (from all git tags)",
+        show_default=True,
+    ),
+    json: bool = option_json,
 ):
     """Print list of stages used in the registry
 
@@ -744,7 +788,11 @@ def stages(
         $ gto stages
         $ gto stages --allowed
     """
-    format_echo(gto.api.get_stages(repo, allowed=allowed), "lines")
+    result = gto.api.get_stages(repo, allowed=allowed, used=used)
+    if json:
+        format_echo(result, "json")
+    else:
+        format_echo(result, "lines")
 
 
 @gto_command(hidden=True)
@@ -767,7 +815,9 @@ def print_index(repo: str = option_repo):
     Examples:
         $ gto print-index
     """
-    index = gto.api.get_index(repo).artifact_centric_representation()
+    index = gto.api._get_index(  # pylint: disable=protected-access
+        repo
+    ).artifact_centric_representation()
     format_echo(index, "json")
 
 
