@@ -1,12 +1,17 @@
 import os
-from typing import Union
+from typing import Optional, Union
 
 import git
 from git import InvalidGitRepositoryError, NoSuchPathError, Repo
 from pydantic import BaseModel
 
 from gto.base import BasePromotion, BaseRegistryState
-from gto.config import CONFIG_FILE_NAME, RegistryConfig, read_registry_config
+from gto.config import (
+    CONFIG_FILE_NAME,
+    RegistryConfig,
+    assert_name_is_valid,
+    read_registry_config,
+)
 from gto.exceptions import (
     NoRepo,
     VersionAlreadyRegistered,
@@ -49,6 +54,15 @@ class GitRegistry(BaseModel):
             enrichment_manager=EnrichmentManager(repo=repo, config=config),
         )
 
+    def is_gto_repo(self):
+        if self.config.config_file_exists():
+            return True
+        if self.config.check_index_exist(self.repo.working_dir):
+            return True
+        if self.get_state() != BaseRegistryState():
+            return True
+        return False
+
     def get_state(
         self,
         all_branches=False,
@@ -89,7 +103,7 @@ class GitRegistry(BaseModel):
             name, create_new=create_new  # type: ignore
         )
 
-    def register(
+    def register(  # pylint: disable=too-many-locals
         self,
         name,
         ref,
@@ -99,8 +113,11 @@ class GitRegistry(BaseModel):
         bump_minor=False,
         bump_patch=False,
         stdout=False,
+        author: Optional[str] = None,
+        author_email: Optional[str] = None,
     ):
         """Register artifact version"""
+        assert_name_is_valid(name)
         version_args = sum(
             bool(i) for i in (version, bump_major, bump_minor, bump_patch)
         )
@@ -146,6 +163,8 @@ class GitRegistry(BaseModel):
             version,
             ref,
             message=message or f"Registering artifact {name} version {version}",
+            author=author,
+            author_email=author_email,
         )
         registered_version = self.find_artifact(name).find_version(
             name=version, raise_if_not_found=True
@@ -156,7 +175,7 @@ class GitRegistry(BaseModel):
             )
         return registered_version
 
-    def promote(
+    def promote(  # pylint: disable=too-many-locals
         self,
         name,
         stage,
@@ -168,8 +187,11 @@ class GitRegistry(BaseModel):
         force=False,
         skip_registration=False,
         stdout=False,
+        author: Optional[str] = None,
+        author_email: Optional[str] = None,
     ) -> BasePromotion:
         """Assign stage to specific artifact version"""
+        assert_name_is_valid(name)
         self.config.assert_stage(stage)
         if not (promote_version is None) ^ (promote_ref is None):
             raise WrongArgs("One and only one of (version, ref) must be specified.")
@@ -205,32 +227,41 @@ class GitRegistry(BaseModel):
             and found_version.stage.stage == stage
         ):
             raise WrongArgs(f"Version is already in stage '{stage}'")
-        self.stage_manager.promote(  # type: ignore
+        # TODO: getting tag name as a result and using it
+        # is leaking implementation details in base module
+        # it's roughly ok to have until we add other implementations
+        # beside tag-based promotions
+        tag = self.stage_manager.promote(  # type: ignore
             name,
             stage,
             ref=promote_ref,
             message=message
             or f"Promoting {name} version {promote_version} to stage {stage}",
             simple=simple,
+            author=author,
+            author_email=author_email,
         )
-        promotion = (
-            self.get_state()
-            .find_artifact(name)
-            .find_version_at_commit(promote_ref)
-            .stage
-        )
+        promotion = self.stage_manager.check_ref(tag, self.get_state())[name]
         if stdout:
             echo(
                 f"Created git tag '{promotion.tag}' that promotes '{promotion.version}'"
             )
         return promotion
 
+    def _check_ref(self, ref, state):
+        if ref.startswith("refs/tags/"):
+            ref = ref[len("refs/tags/") :]
+        if ref.startswith("refs/heads/"):
+            ref = self.repo.commit(ref).hexsha
+        return {
+            "version": self.version_manager.check_ref(ref, state),
+            "stage": self.stage_manager.check_ref(ref, state),
+        }
+
     def check_ref(self, ref: str):
         "Find out what was registered/promoted in this ref"
-        return {
-            "version": self.version_manager.check_ref(ref, self.get_state()),
-            "stage": self.stage_manager.check_ref(ref, self.get_state()),
-        }
+        state = self.get_state()
+        return self._check_ref(ref, state)
 
     def find_commit(self, name, version):
         return self.get_state().find_commit(name, version)
@@ -247,15 +278,29 @@ class GitRegistry(BaseModel):
         """Return latest active version for artifact"""
         artifact = self.get_state().find_artifact(name)
         if all:
-            return artifact.sort_versions(registered=registered)
+            return artifact.get_versions(include_non_explicit=not registered)
         return artifact.get_latest_version(registered_only=registered)
 
-    def get_stages(self, allowed: bool = False):
-        """Return list of stages in the registry.
-        If "allowed", return stages that are allowed in config.
-        """
-        if allowed:
-            return self.config.stages
+    def _get_allowed_stages(self):
+        return self.config.STAGES
+
+    def _get_used_stages(self):
         return sorted(
             {stage for o in self.get_artifacts().values() for stage in o.unique_stages}
         )
+
+    def get_stages(self, allowed: bool = False, used: bool = False):
+        """Return list of stages in the registry.
+        If "allowed", return stages that are allowed in config.
+        If "used", return stages that were used in registry.
+        """
+        assert not (allowed and used), """Either "allowed" or "used" can be set"""
+        if allowed:
+            return self._get_allowed_stages()
+        if used:
+            return self._get_used_stages()
+        # if stages in config are set, return them
+        if self._get_allowed_stages() is not None:
+            return self._get_allowed_stages()
+        # if stages aren't set in config, return those in use
+        return self._get_used_stages()
